@@ -16,7 +16,6 @@ def encrypt_text_with_kms(config_dict, key_id, kms_client=None):
     key = 'alias/%s' % key_id
     try:
         response = kms_client.encrypt(
-            # KeyId=kms_id_arn,
             KeyId=key,
             Plaintext=config_text
         )
@@ -28,13 +27,15 @@ def encrypt_text_with_kms(config_dict, key_id, kms_client=None):
     return encrypted_ciphertext
 
 
-def upload_s3(key_bucket, key_id, encoded_ciphertext, s3_client=None):
+def upload_s3(key_bucket, ssm_key_alias, key_name, encoded_ciphertext, s3_client=None):
     if s3_client is None:
         s3_client = boto3.client('s3',
                                  aws_access_key_id=None,
                                  aws_secret_access_key=None
                                  )
-    key = 'alias/%s' % key_id
+    key = 'alias/%s' % ssm_key_alias
+    if '.json' not in key_name:
+        key_name = key_name + '.json'
     try:
         response = s3_client.put_object(
             ACL='private',
@@ -42,7 +43,7 @@ def upload_s3(key_bucket, key_id, encoded_ciphertext, s3_client=None):
             Bucket=key_bucket,
             ContentType="application/json",
             ServerSideEncryption="aws:kms",
-            SSEKMSKeyId=key_id,
+            SSEKMSKeyId=key_name,
             Key=key
         )
     except Exception as err:
